@@ -78,7 +78,8 @@ class ShapForest(object):
             model = adict["object"]
         else:
             raise ValueError(
-                "Model format not recognized with keys %s", str(sorted(adict.keys()))
+                "Model format not recognized with keys %s",
+                str(sorted(adict.keys())),
             )
 
         roots = [t["root"] for t in model["model"]["trees"]]
